==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/de/templates.php <==
<?php
regGS("The template '$1' was saved successfully.", "Template '$1$ wurde erfolgreich gespeichert.");
regGS("The template $1 is in use and can not be deleted.", "Die Template $1 wird benutzt und kann nicht gelöscht werden.");
regGS("The folder could not be deleted.", "Ordner konnte nicht gelöscht werden");
regGS("The directory must be empty", "Das Verzeichnis muss leer sein.");
regGS("Create new folder", "Neuen Ordner erstellen");
regGS("Upload template", "Template hochladen");
regGS("Creating new folder", "Neuer Ordner wird erstellt");
regGS("You do not have the right to create new folders.", "Keine Berechtigung neuen Ordner zu erstellen");
regGS("The folder $1 could not be created", "Ordner $1 konnte nicht erstellt werden");
regGS("A file or folder having the name $1 already exists", "Eine Datei oder ein Verzeichnis mit dem Namen $1 existiert bereits");
regGS("You do not have the right to delete templates.", "Keine Berechtigung Templates zu löschen");
regGS("Are you sure you want to delete the folder $1 from $2?", "Ordner $1 aus $2 wirklich löschen?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Template $1 aus Ordner $2 wirklich löschen?");
regGS("Deleting template", "Template wird gelöscht");
regGS("Deleting folder", "Ordner wird gelöscht");
regGS("Template $1 was deleted", "Template $1 wurde gelöscht");
regGS("Delete folder", "Ordner löschen");
regGS("Folders", "Ordner");
regGS("No folders.", "Keine Ordner");
regGS("Files", "Dateien");
regGS("No templates.", "Keine Templaters");
regGS("Uploading template", "Template wird hochgeladen");
regGS("File", "Datei");
regGS("Create new template", "Neues Template erstellen");
regGS("Creating new template", "Neues Template wird erstellt");
regGS("Duplicate template", "Template Duplizieren");
regGS("Edit template", "Template Bearbeiten");
regGS("The template $1 could not be created.", "Template $1 konnte nicht erstellt werden");
regGS("Template $1 was changed", "Template $1 wurde geändert");
regGS("New template $1 was created", "Neues Template $1 wurde erstellt");
regGS("Template $1 was duplicated into $2", "Template $1 wurde in $2 dupliziert???");
regGS("Template charset", "Template Charset");
regGS("Select a language/character set", "Sprache / Zeichensatz auswählen");
regGS("All languages", "Alle Sprachen");
regGS("You do not have the right to modify templates.", "Keine Zugriffsrechte auf das Verändern von Templates");
regGS("Invalid template file $1", "Ungültige Templatedatei $1");
regGS("You do not have the right to create folders.", "Kein Zugriffsrechte auf das Erstellen von Verzeichnissen");
regGS("You do not have the right to upload templates.", "Keine Berechtigung Templates hochzuladen");
regGS("You do not have the right to create templates.", "Keine Berechtigung Templates zu erstellen");
regGS("Duplicate file", "Datei duplizieren");
regGS("Delete file", "Datei löschen");
regGS("Unable to save the template '$1' to the path '$2'.", "Fehler beim Speichern der Template '$1' im Pfad '$2'");
regGS("Please check if the user '$1' has permission to write in this directory.", "Bitte überprüfen, ob User '$1' Zugriffsrechte für dieses Verzeichnis hat");
regGS("Unable to delete the template '$1' in the path '$2'.", "Fehler beim Löschen der Template '$1' im Pfad '$2'");
regGS("The folder has been deleted.", "Ordner wurde gelöscht");
regGS("The template has been deleted.", "Template wurde gelöscht");
regGS("The template could not be deleted.", "Template konnte nicht gelöscht werden");
regGS("Save", "Speichern");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/de/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "Template '$1$ wurde erfolgreich gespeichert.");
regGS("The template $1 is in use and can not be deleted.", "Die Template $1 wird benutzt und kann nicht gelöscht werden.");
regGS("Create new folder", "Neuen Ordner erstellen");
regGS("Upload template", "Template hochladen");
regGS("You do not have the right to create new folders.", "Keine Berechtigung neuen Ordner zu erstellen");
regGS("A file or folder having the name $1 already exists", "Eine Datei oder ein Verzeichnis mit dem Namen $1 existiert bereits");
regGS("You do not have the right to delete templates.", "Keine Berechtigung Templates zu löschen");
regGS("Are you sure you want to delete the folder $1 from $2?", "Ordner $1 aus $2 wirklich löschen?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Template $1 aus Ordner $2 wirklich löschen?");
regGS("Template $1 was deleted", "Template $1 wurde gelöscht");
regGS("Delete folder", "Ordner löschen");
regGS("Folders", "Ordner");
regGS("No folders.", "Keine Ordner");
regGS("Files", "Dateien");
regGS("No templates.", "Keine Templaters");
regGS("File", "Datei");
regGS("Create new template", "Neues Template erstellen");
regGS("Duplicate template", "Template Duplizieren");
regGS("Edit template", "Template Bearbeiten");
regGS("The template $1 could not be created.", "Template $1 konnte nicht erstellt werden");
regGS("Template $1 was changed", "Template $1 wurde geändert");
regGS("Template $1 was duplicated into $2", "Template $1 wurde in $2 dupliziert???");
regGS("Template charset", "Template Charset");
regGS("Select a language/character set", "Sprache / Zeichensatz auswählen");
regGS("All languages", "Alle Sprachen");
regGS("You do not have the right to modify templates.", "Keine Zugriffsrechte auf das Verändern von Templates");
regGS("Invalid template file $1", "Ungültige Templatedatei $1");
regGS("You do not have the right to create folders.", "Kein Zugriffsrechte auf das Erstellen von Verzeichnissen");
regGS("You do not have the right to upload templates.", "Keine Berechtigung Templates hochzuladen");
regGS("You do not have the right to create templates.", "Keine Berechtigung Templates zu erstellen");
regGS("Duplicate file", "Datei duplizieren");
regGS("Delete file", "Datei löschen");
regGS("Please check if the user '$1' has permission to write in this directory.", "Bitte überprüfen, ob User '$1' Zugriffsrechte für dieses Verzeichnis hat");
regGS("The folder has been deleted.", "Ordner wurde gelöscht");
regGS("The template has been deleted.", "Template wurde gelöscht");
regGS("The template could not be deleted.", "Template konnte nicht gelöscht werden");
regGS("Save", "Speichern");
?>
